@@ -16,9 +16,8 @@ from opentelemetry.sdk.trace.export import BatchSpanProcessor, ConsoleSpanExport
 from opentelemetry.sdk.trace.sampling import ALWAYS_ON
 
 from common.consts import (
-    METIS_REQUEST_SPAN_ATTRIBUTE_IDENTIFIER,
+    METIS_REQUEST_SPAN_ATTRIBUTE_IDENTIFIER, SENTRY_DSN,
 )
-from common.exporters.file_exporter import MetisFileExporter
 from common.exporters.remote_exporter import MetisRemoteExporter
 from common.plan_collect_type import PlanCollectType
 from common.utils.env_var import extract_additional_tags_from_env_var
@@ -31,8 +30,6 @@ METIS_INSTRUMENTATION_STR = "METIS_INSTRUMENTATION"
 
 logger = logging.getLogger(__name__)
 
-FILE_NAME = "metis-log-collector.log"
-
 os.environ[
     "OTEL_INSTRUMENTATION_HTTP_CAPTURE_HEADERS_SERVER_REQUEST"
 ] = "content-type,custom_request_header"
@@ -103,12 +100,11 @@ def _convert_items_to_metis_tags(tags_dict: Optional[Attributes]):
 @log
 def setup(
         service_name: str,
+        api_key: str,
         service_version: Optional[str] = None,
         resource_tags: Optional[Attributes] = None,
         plan_collection_option: Optional[PlanCollectType] = PlanCollectType.ESTIMATED,
-        file_name: Optional[str] = None,
-        api_key: Optional[str] = None,
-        dsn: Optional[str] = None,
+        dsn: Optional[str] = "https://ingest.metisdata.io/",
         report_errors: bool = True):
     _is_metis_instrumentation_enable = strtobool(os.getenv(METIS_INSTRUMENTATION_STR, 'true'))
     if not _is_metis_instrumentation_enable:
@@ -117,7 +113,7 @@ def setup(
 
     if api_key and report_errors:
         sentry_logger = sentry_sdk.Hub(sentry_sdk.Client(
-            dsn='https://f4732683eb3a40ab9e5a5d4033b246e0@o1173646.ingest.sentry.io/6271090',
+            dsn=SENTRY_DSN,
             traces_sample_rate=1.0,
             with_locals=False,
             request_bodies="never",
@@ -134,7 +130,7 @@ def setup(
                                           plan_collection_option=plan_collection_option,
                                           sentry_logger=sentry_logger)
 
-    metis_interceptor.set_exporters(file_name, api_key, dsn)
+    metis_interceptor.set_exporters(api_key, dsn)
 
     return metis_interceptor
 
@@ -177,26 +173,19 @@ class MetisInstrumentor(metaclass=SingletonMeta):
 
     @log
     def set_exporters(self,
-                      file_name: Optional[str] = None,
                       api_key: Optional[str] = None,
                       dsn: Optional[str] = None):
-        is_set = self.set_exporters_once.do_once(self._set_exporters,
-                                                 file_name=file_name, api_key=api_key, dsn=dsn)
+        is_set = self.set_exporters_once.do_once(self._set_exporters, api_key=api_key, dsn=dsn)
 
         if not is_set:
             logger.warning("You've setup metis instrumentation already")
 
     @log
     def _set_exporters(self,
-                       file_name: Optional[str] = None,
                        api_key: Optional[str] = None,
-                       dsn: Optional[str] = None):
-        if not file_name and not dsn:
-            file_name = os.getenv("METIS_LOG_FILE_NAME", FILE_NAME)
-        if file_name:
-            self._add_processor(BatchSpanProcessor(MetisFileExporter(file_name)))
+                       dsn: Optional[str] = "https://ingest.metisdata.io/"):
         if bool(dsn) != bool(api_key):
-            raise ValueError("Both endpoint and api_key must be provided")
+            raise ValueError("Endpoint and api_key must be provided")
         if dsn is not None:
             self._add_processor(BatchSpanProcessor(MetisRemoteExporter(dsn, api_key, self.sentry_logger)))
 
